agentle.agents.a2a.tasks.task\_query\_params
============================================

.. automodule:: agentle.agents.a2a.tasks.task_query_params

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      BaseModel
      TaskQueryParams
   